==> generator-qccr-startKit-0.0.2.tgz: package/fis.config.js <==
// 构建中去除
fis.set('project.ignore', [
  'output/**',
  'node_modules/**',
  '.git/**',
  '.svn/**',
  'fis-conf.js',
  'package.json',
  'pkg/**'
]);

// prod config
var path = 'xx/xx'; // 发布到线上的路径
var saleUserConfig = require('ftp-sale-config');    // ftp模块

// eslint插件配置
var eslintConf = {
    ignoreFiles: ['js/lib/**.js', 'fis-conf.js'],
    envs: ['browser', 'node'],
    globals: ['$'],
    rules: {
        //Possible Errors
        "no-console": ["warn", { allow: ["warn", "error"] }], // 禁用console.log
        "no-debugger": ["error"],                             // 禁用debugger
        "no-duplicate-case": ["error"],                       // 禁用重复的case标签
        "no-dupe-args": ["warn"],                             // 禁用function定义中出现重名参数
        "no-extra-semi": ["warn"],                            // 禁止不必要的分号
        "no-func-assign": ["error"],                          // 禁止对 function 声明重新赋值
        "no-inner-declarations": ["warn"],                    // 禁止在嵌套的块中出现 function 或 var 声明
        "no-obj-calls": ["error"],                            // 禁止把全局对象 (Math 和 JSON) 作为函数调用
        "no-unreachable": ["error"],                          // 禁止在return、throw、continue 和 break语句之后出现不可达代码
        "no-unsafe-finally": ["error"],                       // 禁止在 finally 语句块中出现控制流语句
        "use-isnan": ["error"],                               // 要求使用 isNaN() 检查 NaN
        "valid-typeof": ["error"],                            // 强制 typeof 表达式与有效的字符串进行比较
        //Best Practices
        "block-scoped-var": ["warn"],                         // 强制把变的使用限制在其定义的作用域范围内
        "consistent-return": ["error"],                       // 要求 return 语句要么总是指定返回的值，要么不指定
        "curly": ["warn"],                                    // 强制所有控制语句使用一致的括号风格
        "default-case": ["warn"],                             // 要求 switch 语句中有 default 分支
        "no-alert": ["warn"],                                 // 禁用 alert、confirm 和 prompt
        "no-caller": ["warn"],                                // 禁用 arguments.caller 或 arguments.callee
        "no-empty-function": ["warn"],                        // 禁止出现空函数
        "no-eq-null": ["warn"],                               // 禁止在没有类型检查操作符的情况下与 null 进行比较
        "no-eval": ["warn"],                                  // 禁用 eval()
        "no-extend-native": ["warn"],                         // 禁止扩展原生类型
        "no-fallthrough": ["warn"],                           // 禁止 case 语句落空
        "no-loop-func": ["warn"],                             // 禁止在循环中出现 function 声明和表达式
        "no-native-reassign": ["warn"],                       // 禁止对原生对象赋值
        "no-redeclare": ["warn"],                             // 禁止使用 var 多次声明同一变量
        "no-unused-labels": ["warn"],                         // 禁用未使用过的标签
        "no-self-assign": ["warn"],                           // 禁止自我赋值
        "no-octal": ["warn"],                                 // 禁用八进制字面量
        //relate to variables
        "no-delete-var": ["warn"],                            // 禁止删除变量
        "no-unused-vars": ["warn"],                           // 禁止出现未使用过的变量
        "no-undef": ["warn"],                                 // 禁用未声明的变量，除非它们在 /*global*/ 注释中被提到
        //relate to es6
        "constructor-super": ["warn"],                        // 要求在构造函数中有 super() 的调用
        "no-class-assign": ["warn"],                          // 禁止修改类声明的变量
        "no-const-assign": ["error"],                         // 禁止修改 const 声明的变量
        "no-dupe-class-members": ["warn"],                    // 禁止类成员中出现重复的名称
        "no-this-before-super": ["warn"],                     // 禁止在构造函数中，在调用 super() 之前使用 this 或 super
        "no-mixed-spaces-and-tabs": ["warn"],                 // 不允许空格和 tab 混合缩进
    }
};

//接口替换,如果存在测试或者灰度接口,替换为线上接口
function replaceAPI(content){
    content = content.replace("http://192.168.3.213:9775", "http://api.qichechaoren.com").replace("http://huiduapi.qichechaoren.com", "http://api.qichechaoren.com");
    return content;
}
//添加统计代码
function addAD(content){
    var hasAD = content.match(/\traffics\.js/g);
    if(!hasAD){
        content = content.replace("</body>", "</body><script src='http://sale.qccr.com/js/traffics.js'></script>");
    }
    return content;
}

fis.match('*.js', {
    parser: replaceAPI, // 替换非生产环境接口
    optimizer: fis.plugin("uglify-js"),     // js压缩
    lint: fis.plugin('eslint', eslintConf)	// js验证
});

fis.match('*.*html', {
    parser: addAD
});

fis.match('*.{js,css,png,gif,jpg}', {
    useHash: true, // 开启 md5 戳
    url : '//sale.qccr.com/' + path + '$0' // 匹配到sale服务器目录
});

fis.match('*.png', {
  // fis-optimizer-png-compressor 插件进行压缩，已内置
  optimizer: fis.plugin('png-compressor')
});

// 启用 fis-spriter-csssprites 插件
fis.match('::package', {
  spriter: fis.plugin('csssprites')
});

fis.match('*.css', {
    useSprite: true,    				// 启用雪碧图 *.png?__sprite
    optimizer: fis.plugin('clean-css')  // css压缩
});

fis.media('publish').match('*', {
    deploy: fis.plugin('ftp', {
        //console: true,
        cache : true,           		// 是否开启上传列表缓存，开启后支持跳过未修改文件，默认：true
        remoteDir : '/' + path + '/',   // 远程文件目录，注意！！！设置错误将导致文件被覆盖
        connect : {
            host : '124.160.126.58',
            port : '21',
            user : saleUserConfig.getConfig().user,
            password : saleUserConfig.getConfig().password
        }
    })
});

==> generator-qccr-startKit-0.0.3.tgz: package/fis.config.js <==
// 构建中去除
fis.set('project.ignore', [
  'output/**',
  'node_modules/**',
  '.git/**',
  '.svn/**',
  'fis-conf.js',
  'package.json',
  'pkg/**'
]);

// prod config
var path = 'xx/xx'; // 发布到线上的路径
var saleUserConfig = require('ftp-sale-config');    // ftp模块

// eslint插件配置
var eslintConf = {
    ignoreFiles: ['js/lib/**.js', 'fis-conf.js'],
    envs: ['browser', 'node'],
    globals: ['$'],
    rules: {
        //Possible Errors
        "no-console": ["warn", { allow: ["warn", "error"] }], // 禁用console.log
        "no-debugger": ["error"],                             // 禁用debugger
        "no-duplicate-case": ["error"],                       // 禁用重复的case标签
        "no-dupe-args": ["warn"],                             // 禁用function定义中出现重名参数
        "no-extra-semi": ["warn"],                            // 禁止不必要的分号
        "no-func-assign": ["error"],                          // 禁止对 function 声明重新赋值
        "no-inner-declarations": ["warn"],                    // 禁止在嵌套的块中出现 function 或 var 声明
        "no-obj-calls": ["error"],                            // 禁止把全局对象 (Math 和 JSON) 作为函数调用
        "no-unreachable": ["error"],                          // 禁止在return、throw、continue 和 break语句之后出现不可达代码
        "no-unsafe-finally": ["error"],                       // 禁止在 finally 语句块中出现控制流语句
        "use-isnan": ["error"],                               // 要求使用 isNaN() 检查 NaN
        "valid-typeof": ["error"],                            // 强制 typeof 表达式与有效的字符串进行比较
        //Best Practices
        "block-scoped-var": ["warn"],                         // 强制把变的使用限制在其定义的作用域范围内
        "consistent-return": ["error"],                       // 要求 return 语句要么总是指定返回的值，要么不指定
        "curly": ["warn"],                                    // 强制所有控制语句使用一致的括号风格
        "default-case": ["warn"],                             // 要求 switch 语句中有 default 分支
        "no-alert": ["warn"],                                 // 禁用 alert、confirm 和 prompt
        "no-caller": ["warn"],                                // 禁用 arguments.caller 或 arguments.callee
        "no-empty-function": ["warn"],                        // 禁止出现空函数
        "no-eq-null": ["warn"],                               // 禁止在没有类型检查操作符的情况下与 null 进行比较
        "no-eval": ["warn"],                                  // 禁用 eval()
        "no-extend-native": ["warn"],                         // 禁止扩展原生类型
        "no-fallthrough": ["warn"],                           // 禁止 case 语句落空
        "no-loop-func": ["warn"],                             // 禁止在循环中出现 function 声明和表达式
        "no-native-reassign": ["warn"],                       // 禁止对原生对象赋值
        "no-redeclare": ["warn"],                             // 禁止使用 var 多次声明同一变量
        "no-unused-labels": ["warn"],                         // 禁用未使用过的标签
        "no-self-assign": ["warn"],                           // 禁止自我赋值
        "no-octal": ["warn"],                                 // 禁用八进制字面量
        //relate to variables
        "no-delete-var": ["warn"],                            // 禁止删除变量
        "no-unused-vars": ["warn"],                           // 禁止出现未使用过的变量
        "no-undef": ["warn"],                                 // 禁用未声明的变量，除非它们在 /*global*/ 注释中被提到
        //relate to es6
        "constructor-super": ["warn"],                        // 要求在构造函数中有 super() 的调用
        "no-class-assign": ["warn"],                          // 禁止修改类声明的变量
        "no-const-assign": ["error"],                         // 禁止修改 const 声明的变量
        "no-dupe-class-members": ["warn"],                    // 禁止类成员中出现重复的名称
        "no-this-before-super": ["warn"],                     // 禁止在构造函数中，在调用 super() 之前使用 this 或 super
        "no-mixed-spaces-and-tabs": ["warn"],                 // 不允许空格和 tab 混合缩进
    }
};

//接口替换,如果存在测试或者灰度接口,替换为线上接口
function replaceAPI(content){
    content = content.replace("http://192.168.3.213:9775", "http://api.qichechaoren.com").replace("http://huiduapi.qichechaoren.com", "http://api.qichechaoren.com");
    return content;
}
//添加统计代码
function addAD(content){
    var hasAD = content.match(/\traffics\.js/g);
    if(!hasAD){
        content = content.replace("</body>", "</body><script src='http://sale.qccr.com/js/traffics.js'></script>");
    }
    return content;
}

fis.match('*.js', {
    parser: replaceAPI, // 替换非生产环境接口
    optimizer: fis.plugin("uglify-js"),     // js压缩
    lint: fis.plugin('eslint', eslintConf)	// js验证
});

fis.match('*.*html', {
    parser: addAD
});

fis.match('*.{js,css,png,gif,jpg}', {
    useHash: true, // 开启 md5 戳
    url : '//sale.qccr.com/' + path + '$0' // 匹配到sale服务器目录
});

fis.match('*.png', {
  // fis-optimizer-png-compressor 插件进行压缩，已内置
  optimizer: fis.plugin('png-compressor')
});

// 启用 fis-spriter-csssprites 插件
fis.match('::package', {
  spriter: fis.plugin('csssprites')
});

fis.match('*.css', {
    useSprite: true,    				// 启用雪碧图 *.png?__sprite
    optimizer: fis.plugin('clean-css')  // css压缩
});

fis.media('upload').match('*', {
    deploy: fis.plugin('ftp', {
        //console: true,
        cache : true,           		// 是否开启上传列表缓存，开启后支持跳过未修改文件，默认：true
        remoteDir : '/' + path + '/',   // 远程文件目录，注意！！！设置错误将导致文件被覆盖
        connect : {
            host : '124.160.126.58',
            port : '21',
            user : saleUserConfig.getConfig().user,
            password : saleUserConfig.getConfig().password
        }
    })
});
